@@ -316,6 +316,58 @@ def write_delta_stream_with_custom_fnc(spark_job_conf, output_name: str, stream:
             .start(output_stream_conf['delta_options']['location'])
 
 
+def write_delta_stream_with_custom_fnc_same_foreach_batch(spark_job_conf: dict, output_name: str, stream: DataFrame,
+                                                          updater_function):
+    output_stream_conf = get_spark_conf(output_name, spark_job_conf['outputs'])
+    # for output in output_stream_conf['delta_options']:
+    #     DeltaTable \
+    #         .createIfNotExists() \
+    #         .addColumns(output['schema']) \
+    #         .partitionedBy(output["partition_columns"]) \
+    #         .location(output["location"]) \
+    #         .execute()
+
+    if output_stream_conf.get('processing_time') is not None:
+        stream \
+            .writeStream \
+            .queryName(output_stream_conf['name']) \
+            .format("delta") \
+            .outputMode(output_stream_conf['mode']) \
+            .trigger(processingTime=output_stream_conf['processing_time']) \
+            .foreachBatch(updater_function) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
+            .start()
+    elif output_stream_conf.get('availableNow') is not None:
+        stream \
+            .writeStream \
+            .queryName(output_stream_conf['name']) \
+            .format("delta") \
+            .outputMode(output_stream_conf['mode']) \
+            .trigger(availableNow=output_stream_conf['availableNow']) \
+            .foreachBatch(updater_function) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
+            .start()
+    elif output_stream_conf.get('once') is not None:
+        stream \
+            .writeStream \
+            .queryName(output_stream_conf['name']) \
+            .format("delta") \
+            .outputMode(output_stream_conf['mode']) \
+            .trigger(once=output_stream_conf['once']) \
+            .foreachBatch(updater_function) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
+            .start()
+    else:
+        stream \
+            .writeStream \
+            .queryName(output_stream_conf['name']) \
+            .format("delta") \
+            .outputMode(output_stream_conf['mode']) \
+            .foreachBatch(updater_function) \
+            .option("checkpointLocation", output_stream_conf['checkpoint_location']) \
+            .start()
+
+
 ########
 # AVRO #
 ########
